# Flybys in `REBOUND`
- A package for implementing flybys in [hannorein/rebound](https://github.com/hannorein/rebound)

**Package Prerequisites**
- `numpy`
- `scipy`

## Examples
- A Basic Flyby Setup
- Sampling the effects of a stellar environment

<img src="/examples/images/hyperbolic_trajectories.png" alt="Hyperbolic trajectories with different impact parameters" height="400" width="450">
